@@ -25,10 +25,10 @@ impl std::fmt::Display for Scheme {
     }
 }
 
-impl<'a> std::convert::TryFrom<Tokenizer<'a, &'a [u8]>> for Scheme {
+impl<'a> std::convert::TryFrom<Tokenizer<'a, &'a [u8], u8>> for Scheme {
     type Error = crate::Error;
 
-    fn try_from(tokenizer: Tokenizer<'a, &'a [u8]>) -> Result<Self, Self::Error> {
+    fn try_from(tokenizer: Tokenizer<'a, &'a [u8], u8>) -> Result<Self, Self::Error> {
         use std::str::from_utf8;
 
         match from_utf8(tokenizer.value)? {
@@ -38,10 +38,10 @@ impl<'a> std::convert::TryFrom<Tokenizer<'a, &'a [u8]>> for Scheme {
     }
 }
 
-impl<'a> std::convert::TryFrom<Tokenizer<'a, &'a str>> for Scheme {
+impl<'a> std::convert::TryFrom<Tokenizer<'a, &'a str, char>> for Scheme {
     type Error = crate::Error;
 
-    fn try_from(tokenizer: Tokenizer<'a, &'a str>) -> Result<Self, Self::Error> {
+    fn try_from(tokenizer: Tokenizer<'a, &'a str, char>) -> Result<Self, Self::Error> {
         match tokenizer.value {
             part if part.eq_ignore_ascii_case("digest") => Ok(Self::Digest),
             part => Ok(Self::Other(part.into())),
@@ -51,41 +51,48 @@ impl<'a> std::convert::TryFrom<Tokenizer<'a, &'a str>> for Scheme {
 
 #[doc(hidden)]
 mod tokenizer {
-    use crate::AbstractInput;
-    use crate::GenericNomError;
+    use crate::{AbstractInput, GResult, GenericNomError, TokenizerError};
     use std::marker::PhantomData;
 
     #[derive(Debug, PartialEq, Eq, Clone)]
-    pub struct Tokenizer<'a, T>
+    pub struct Tokenizer<'a, T, I>
     where
-        T: AbstractInput<'a>,
+        T: AbstractInput<'a, I>,
+        I: nom::AsChar,
     {
         pub value: T,
-        phantom: PhantomData<&'a T>,
+        phantom1: PhantomData<&'a T>,
+        phantom2: PhantomData<I>,
     }
 
-    impl<'a, T> From<T> for Tokenizer<'a, T>
+    impl<'a, T, I> From<T> for Tokenizer<'a, T, I>
     where
-        T: AbstractInput<'a>,
+        T: AbstractInput<'a, I>,
+        I: nom::AsChar,
     {
         fn from(value: T) -> Self {
             Self {
                 value,
-                phantom: PhantomData,
+                phantom1: PhantomData,
+                phantom2: PhantomData,
             }
         }
     }
 
-    impl<'a, T> Tokenizer<'a, T>
+    impl<'a, T, I> Tokenizer<'a, T, I>
     where
-        T: AbstractInput<'a>,
+        T: AbstractInput<'a, I>,
+        I: nom::AsChar,
     {
-        pub fn tokenize(part: T) -> Result<(T, Self), GenericNomError<'a, T>> {
+        pub fn tokenize(part: T) -> GResult<T, Self> {
             use nom::{branch::alt, bytes::complete::take_until, combinator::rest};
 
-            let (rem, scheme) = alt((take_until(" "), rest))(part)?;
+            let (rem, scheme) =
+                alt((take_until(" "), rest))(part).map_err(|_: GenericNomError<'a, T>| {
+                    TokenizerError::from(("scheme (header)", part)).into()
+                })?;
 
-            Ok((rem, scheme.into()))
+            Ok((rem, Self::from(scheme)))
         }
     }
 }
