@@ -121,7 +121,7 @@ impl std::fmt::Display for Header {
 #[doc(hidden)]
 pub mod tokenizer {
     use super::*;
-    use crate::{Error, NomError};
+    use crate::{Error, IResult, TokenizerError};
     use rsip_derives::Utf8Tokenizer;
     use std::convert::TryInto;
 
@@ -269,20 +269,26 @@ pub mod tokenizer {
     }
 
     impl<'a> Tokenizer<'a> {
-        pub fn tokenize(part: &'a [u8]) -> Result<(&'a [u8], Self), NomError<'a>> {
+        pub fn tokenize(part: &'a [u8]) -> IResult<Self> {
+            use crate::NomError;
             use nom::{
-                bytes::complete::{tag, take_until},
+                branch::alt,
+                bytes::complete::{tag, take_until, take_while1},
                 character::complete::space0,
+                combinator::{map, rest},
                 sequence::tuple,
             };
 
-            let (rem, (name, _, _, value, _)) = tuple((
-                take_until(":"),
+            let (rem, (name, _, _, value)) = tuple((
+                take_while1(crate::parser_utils::is_token),
                 tag(":"),
                 space0,
-                take_until("\r\n"),
-                tag("\r\n"),
-            ))(part)?;
+                alt((
+                    map(tuple((take_until("\r\n"), tag("\r\n"))), |(value, _)| value),
+                    rest,
+                )),
+            ))(part)
+            .map_err(|_: NomError<'a>| TokenizerError::from(("header", part)).into())?;
 
             Ok((rem, (name, value).into()))
         }
