@@ -1,7 +1,7 @@
 #[doc(hidden)]
 pub use super::tokenizers::UriWithParamsListTokenizer as Tokenizer;
 
-use crate::common::uri::UriWithParamsList;
+use crate::common::uri::{UriWithParams, UriWithParamsList};
 use rsip_derives::TypedHeader;
 use std::convert::TryFrom;
 
@@ -9,6 +9,12 @@ use std::convert::TryFrom;
 #[derive(TypedHeader, Eq, PartialEq, Clone, Debug)]
 pub struct ErrorInfo(pub UriWithParamsList);
 
+impl ErrorInfo {
+    pub fn uris(&self) -> &[UriWithParams] {
+        self.0.uris()
+    }
+}
+
 impl From<UriWithParamsList> for ErrorInfo {
     fn from(uri_with_params_list: UriWithParamsList) -> Self {
         Self(uri_with_params_list)
