@@ -1,7 +1,8 @@
 mod auth;
 mod cseq;
 mod display_uri_params;
-mod media_type;
+mod name_params;
+mod name_params_list;
 mod name_value;
 mod token_list;
 mod uri_with_params;
@@ -13,7 +14,8 @@ mod warning;
 pub use auth::AuthTokenizer;
 pub use cseq::CseqTokenizer;
 pub use display_uri_params::DisplayUriParamsTokenizer;
-pub use media_type::{MediaTypeListTokenizer, MediaTypeTokenizer};
+pub use name_params::NameParamsTokenizer;
+pub use name_params_list::NameParamsListTokenizer;
 pub use name_value::NameValueTokenizer;
 pub use token_list::TokenListTokenizer;
 pub use uri_with_params::UriWithParamsTokenizer;
