@@ -1,3 +1,4 @@
+use crate::Error;
 use rsip_derives::UntypedHeader;
 
 /// The `Expires` header in its [untyped](super) form.
@@ -17,3 +18,11 @@ impl From<u32> for Expires {
         Self(from.to_string())
     }
 }
+
+impl std::convert::TryFrom<Expires> for u32 {
+    type Error = Error;
+
+    fn try_from(from: Expires) -> Result<Self, Self::Error> {
+        from.seconds()
+    }
+}
