@@ -1,3 +1,4 @@
+use crate::Error;
 use rsip_derives::UntypedHeader;
 
 /// The `Max-Forwards` header in its [untyped](super) form.
@@ -23,3 +24,11 @@ impl From<u32> for MaxForwards {
         Self(from.to_string())
     }
 }
+
+impl std::convert::TryFrom<MaxForwards> for u32 {
+    type Error = Error;
+
+    fn try_from(from: MaxForwards) -> Result<Self, Self::Error> {
+        from.num()
+    }
+}
