@@ -1,7 +1,7 @@
 pub mod auth;
 pub mod display_uri_params;
-pub mod media_type;
-pub mod media_type_list;
+pub mod name_params;
+pub mod name_params_list;
 pub mod name_value;
 pub mod token_list;
 pub mod value;
